@@ -2,36 +2,37 @@
 Module for jenkinsapi ResultSet
 """
 
+from __future__ import annotations
+
 from jenkinsapi.jenkinsbase import JenkinsBase
 from jenkinsapi.result import Result
 
 
 class ResultSet(JenkinsBase):
-
     """
     Represents a result from a completed Jenkins run.
     """
 
-    def __init__(self, url, build):
+    def __init__(self, url: str, build: "Build") -> None:
         """
         Init a resultset
         :param url: url for a build, str
         :param build: build obj
         """
-        self.build = build
+        self.build: "Build" = build
         JenkinsBase.__init__(self, url)
 
-    def get_jenkins_obj(self):
+    def get_jenkins_obj(self) -> "Jenkins":
         return self.build.job.get_jenkins_obj()
 
-    def __str__(self):
+    def __str__(self) -> str:
         return "Test Result for %s" % str(self.build)
 
     @property
     def name(self):
         return str(self)
 
-    def keys(self):
+    def keys(self) -> list[str]:
         return [a[0] for a in self.iteritems()]
 
     def items(self):
