@@ -23,8 +23,7 @@ class Views(object):
     MY_VIEW = "hudson.model.MyView"
     DASHBOARD_VIEW = "hudson.plugins.view.dashboard.Dashboard"
     PIPELINE_VIEW = (
-        "au.com.centrumsystems.hudson."
-        "plugin.buildpipeline.BuildPipelineView"
+        "au.com.centrumsystems.hudson.plugin.buildpipeline.BuildPipelineView"
     )
 
     def __init__(self, jenkins):
