@@ -1,6 +1,7 @@
 """
 System tests for `jenkinsapi.jenkins` module.
 """
+
 import logging
 import pytest
 from jenkinsapi_tests.test_utils.random_strings import random_string
@@ -39,7 +40,7 @@ def test_create_user_pass_credential(jenkins):
 
     cred = creds[cred_descr]
     assert isinstance(cred, UsernamePasswordCredential) is True
-    assert cred.password is None
+    assert cred.password == ""
     assert cred.description == cred_descr
 
     del creds[cred_descr]
