@@ -1,6 +1,7 @@
 """
 System tests for `jenkinsapi.plugins` module.
 """
+
 import logging
 import pytest
 from jenkinsapi_tests.test_utils.random_strings import random_string
@@ -16,7 +17,7 @@ def test_plugin_data(jenkins):
     jenkins.plugins.check_updates_server()
     jenkins.requester.timeout = timeout
 
-    assert "mailer" in jenkins.plugins
+    assert "workflow-api" in jenkins.plugins
 
 
 def test_get_missing_plugin(jenkins):
